==> huaweicloudsdkcsms-3.1.137-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/show_secret_function_templates_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSecretFunctionTemplatesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'function_templates': 'str'
    }

    attribute_map = {
        'function_templates': 'function_templates'
    }

    def __init__(self, function_templates=None):
        """ShowSecretFunctionTemplatesResponse

        The model defined in huaweicloud sdk

        :param function_templates: 凭据轮转函数模板。
        :type function_templates: str
        """
        
        super(ShowSecretFunctionTemplatesResponse, self).__init__()

        self._function_templates = None
        self.discriminator = None

        if function_templates is not None:
            self.function_templates = function_templates

    @property
    def function_templates(self):
        """Gets the function_templates of this ShowSecretFunctionTemplatesResponse.

        凭据轮转函数模板。

        :return: The function_templates of this ShowSecretFunctionTemplatesResponse.
        :rtype: str
        """
        return self._function_templates

    @function_templates.setter
    def function_templates(self, function_templates):
        """Sets the function_templates of this ShowSecretFunctionTemplatesResponse.

        凭据轮转函数模板。

        :param function_templates: The function_templates of this ShowSecretFunctionTemplatesResponse.
        :type function_templates: str
        """
        self._function_templates = function_templates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSecretFunctionTemplatesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcsms-3.1.146-py2.py3-none-any.whl: huaweicloudsdkcsms/v1/model/show_secret_function_templates_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSecretFunctionTemplatesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'function_templates': 'str'
    }

    attribute_map = {
        'function_templates': 'function_templates'
    }

    def __init__(self, function_templates=None):
        r"""ShowSecretFunctionTemplatesResponse

        The model defined in huaweicloud sdk

        :param function_templates: 凭据轮转函数模板。
        :type function_templates: str
        """
        
        super(ShowSecretFunctionTemplatesResponse, self).__init__()

        self._function_templates = None
        self.discriminator = None

        if function_templates is not None:
            self.function_templates = function_templates

    @property
    def function_templates(self):
        r"""Gets the function_templates of this ShowSecretFunctionTemplatesResponse.

        凭据轮转函数模板。

        :return: The function_templates of this ShowSecretFunctionTemplatesResponse.
        :rtype: str
        """
        return self._function_templates

    @function_templates.setter
    def function_templates(self, function_templates):
        r"""Sets the function_templates of this ShowSecretFunctionTemplatesResponse.

        凭据轮转函数模板。

        :param function_templates: The function_templates of this ShowSecretFunctionTemplatesResponse.
        :type function_templates: str
        """
        self._function_templates = function_templates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSecretFunctionTemplatesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
